import {provide} from '@angular/core';
import {ConstructApi} from "../src/construct";
import {Http, HTTP_PROVIDERS, BaseRequestOptions, XHRBackend, Response, ResponseOptions} from '@angular/http';
import {MockBackend, MockConnection} from '@angular/http/testing';

import {
  describe,
  expect,
  beforeEach,
  it,
  inject,
  injectAsync,
  beforeEachProviders
} from '@angular/core/testing';


describe('Construct API Tests', () => {

  beforeEachProviders(() => {
    return [
      HTTP_PROVIDERS,
      provide(XHRBackend, { useClass: MockBackend }),
      ConstructApi
    ];
  });

  it('should query the api',
    inject([XHRBackend, ConstructApi], (mockBackend, api) => {

      // first we register a mock response - when a connection 
      // comes in, we will respond by giving it an array of (one)
      // blog entries
      mockBackend.connections.subscribe(
        (connection: MockConnection) => {
          connection.mockRespond(new Response(
            new ResponseOptions({
              body: [
                {
                  results: [

                  ]
                }]
            }
            )));
        });
        
      // with our mock response configured, we now can 
      // ask the blog service to get our blog entries
      // and then test them
      api.get().subscribe((data: any) => {
        expect(data.results).toBeDefined();
      });
    }));
});
