"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var core_1 = require('@angular/core');
var http_1 = require('@angular/http');
var Observable_1 = require('rxjs/Observable');
require('rxjs/Rx');
var ConstructApi = (function () {
    function ConstructApi(http) {
        this.http = http;
        this._baseParams = {
            lang: 'en'
        };
        this._getParams = {
            limit: 100,
            offset: 0,
            lang: 'en'
        };
    }
    ConstructApi.prototype.headers = function (customHeaders) {
        var httpHeaders = new http_1.Headers({
            'x-accela-appid': this.appId,
            'x-accela-agency': this.agency,
            'x-accela-environment': this.environment
        });
        if (this.authToken) {
            httpHeaders.append('Authorization', this.authToken);
        }
        if (customHeaders) {
            for (var key in customHeaders) {
                httpHeaders.append(key, customHeaders[key]);
            }
        }
        return httpHeaders;
    };
    ConstructApi.prototype.url = function (path, userParams, baseParams) {
        if (baseParams === void 0) { baseParams = this._baseParams; }
        var params = baseParams;
        if (userParams) {
            Object.assign(params, userParams);
        }
        var urlParams = Object.keys(params).map(function (k) {
            return k + "=" + encodeURI(params[k]);
        }).join('&');
        return "" + this.apiHost + path + "?" + urlParams;
    };
    ConstructApi.prototype.setup = function (config) {
        this.appId = config.appId;
        this.apiHost = config.apiHost;
    };
    ConstructApi.prototype.setAuthToken = function (authToken) {
        this.authToken = authToken;
    };
    ConstructApi.prototype.setAgency = function (agency) {
        this.agency = agency;
    };
    ConstructApi.prototype.setEnvironment = function (environment) {
        this.environment = environment;
    };
    ConstructApi.prototype.get = function (path, urlParameters, customHeaders, maxItems) {
        if (maxItems === void 0) { maxItems = 500; }
        var self = this;
        var pageOffset = (urlParameters && urlParameters.offset) ? urlParameters.offset : self._getParams.offset;
        return Observable_1.Observable.create(function (obs) {
            function getPage(offset, count) {
                if (count === void 0) { count = 0; }
                self.http.get(self.url(path, urlParameters, self._getParams), { headers: self.headers(customHeaders) })
                    .map(function (res) { return res.json(); })
                    .subscribe(function (data) {
                    if (!data.result) {
                        data.result = [];
                    }
                    obs.next(data.result);
                    if (data.page && data.page.hasmore && count < maxItems) {
                        getPage(data.page.limit + data.page.offset, count + data.result.length);
                    }
                    else {
                        obs.complete();
                    }
                }, function (error) {
                    obs.error(JSON.stringify(error));
                });
            }
            getPage(pageOffset);
        })
            .flatMap(function (result) {
            return result;
        });
    };
    ConstructApi.prototype.batch = function (path, urlParams, customHeaders) {
        if (path instanceof Array) {
            var request = [];
            for (var i = 0; i < path.length; i++) {
                var tmpReq = {
                    relativeUrl: path[i],
                    method: 'GET'
                };
                request.push(tmpReq);
            }
            var requestData = JSON.stringify(request);
            return this.post('/v4/batch', requestData, null, null);
        }
    };
    ConstructApi.prototype.download = function (path, urlParameters, customHeaders) {
        // this will error out
        // no blob response type implemented on angular 2 yet
        return this.http.get(this.url(path, urlParameters), { headers: this.headers(customHeaders) })
            .map(function (res) { return res.blob(); });
    };
    ConstructApi.prototype.post = function (path, body, urlParameters, customHeaders) {
        return this.http.post(this.url(path, urlParameters), JSON.stringify(body), { headers: this.headers(customHeaders) })
            .map(function (res) { return res.json()['result'] || []; });
    };
    // like post but for searches where response can be in pages
    ConstructApi.prototype.search = function (path, body, urlParameters, customHeaders, maxItems) {
        if (maxItems === void 0) { maxItems = 500; }
        var self = this;
        var pageOffset = (urlParameters && urlParameters.offset) ? urlParameters.offset : self._getParams.offset;
        if (urlParameters && urlParameters.limit) {
            maxItems = urlParameters.limit;
        }
        return Observable_1.Observable.create(function (obs) {
            function getPage(offset, count) {
                if (count === void 0) { count = 0; }
                self.http.post(self.url(path, urlParameters, self._getParams), JSON.stringify(body), { headers: self.headers(customHeaders) })
                    .map(function (res) { return res.json(); })
                    .subscribe(function (data) {
                    if (!data.result) {
                        data.result = [];
                    }
                    obs.next(data.result);
                    count += data.result.length;
                    if (data.page && data.page.hasmore && (count < maxItems)) {
                        getPage(data.page.limit + data.page.offset, count);
                    }
                    else {
                        obs.complete();
                    }
                }, function (error) {
                    obs.error(error);
                });
            }
            getPage(pageOffset);
        })
            .flatMap(function (result) {
            return result;
        });
    };
    ConstructApi.prototype.update = function (path, body, urlParameters, customHeaders) {
        return this.http.put(this.url(path, urlParameters), JSON.stringify(body), { headers: this.headers(customHeaders) })
            .map(function (res) { return res.json()['result'] || []; });
    };
    ConstructApi.prototype.del = function (path, urlParameters, customHeaders) {
        return this.http.delete(this.url(path, urlParameters), { headers: this.headers(customHeaders) })
            .map(function (res) { return res.json()['result'] || []; });
    };
    ConstructApi = __decorate([
        core_1.Injectable(), 
        __metadata('design:paramtypes', [http_1.Http])
    ], ConstructApi);
    return ConstructApi;
}());
exports.ConstructApi = ConstructApi;
//# sourceMappingURL=construct.js.map