import {Injectable} from '@angular/core';
import {Http, Headers, Response} from '@angular/http';
import {Observable} from 'rxjs/Observable';
import {ConstructApi} from '../construct';

@Injectable()
export class InspectionChecklistItemsApi {
  private _basePath = '/v4/inspections';

  constructor(private construct: ConstructApi) { }

  private buildPath(...args) {
    if (!args) {
      return this._basePath;
    }

    return `${this._basePath}/${args.join('/')}`
  }

  // private buildChecklistItemPath(inspectionId, checklistId, checklistItemId) {
  //   return `/${inspectionId}/checklists/${checklistId}/checklistItems/${checklistItemId}`;
  // }

  private checklistItemPath(inspectionId, checklistId, checklistItemId) {
    let slug = `/${inspectionId}/checklists/${checklistId}/checklistItems/${checklistItemId}`;
    let self = this;
    return function(...args) {
      return self.buildPath(slug, args);
    }
  }

  // GET /v4/inspections/{inspectionId}/checklists/{checklistId}/checklistItems
  get(inspectionId:number, checklistId:number, urlParams?, headers?) {
    return this.construct.get(`${this._basePath}/${inspectionId}/checklists/${checklistId}/checklistItems`, urlParams, headers);
  }

  // GET /v4/inspections/{inspectionId}/checklists/{checklistId}/checklistItems/{checklistItemId}/statuses
  getStatuses(inspectionId: number, checklistId:number, checklistItemId:number, urlParams?, headers?) {
    return this.construct.get(`${this._basePath}/${inspectionId}/checklists/${checklistId}/checklistItems/${checklistItemId}/statuses`, urlParams, headers);
  }

  // GET /v4/inspections/{inspectionId}/checklists/{checklistId}/checklistItems/{checklistItemId}/histories
  getHistories(inspectionId: number, checklistId:number, checklistItemId: number, urlParams?, headers?) {
    return this.construct.get(`${this._basePath}/${inspectionId}/checklists/${checklistId}/checklistItems/${checklistItemId}/histories`, urlParams, headers);
  }

  // PUT /v4/inspections/ checklists / { id } / checklistItems
  update(checklistId:number, urlParams?, headers?) {
    return this.construct.get(`${this._basePath}/${checklistId}/checklistItems`, urlParams, headers);
  }

  // GET /v4/inspections/ { id } / checklists / { checklistId } / checklistItems / { checklistItemId } / customForms / meta
  getCustomForms(inspectionId: number, checklistId: number, checklistItemId: number, urlParams?, headers?) {
    let path = `${this._basePath}/${inspectionId}/checklists/${checklistId}/checklistItems/${checklistItemId}/customForms/meta`;

    return this.construct.get(path, urlParams, headers)
      .map((data) => {
        return data.map((item) => {
          item.fields.map((i) => {
            i.value = i.value || null;
          })
          return item;
        })
      });
  }

  getCustomForm(inspectionId: number, checklistId: number, checklistItemId: number, formId:string, urlParams?, headers?) {
    let path = `${this._basePath}/${inspectionId}/checklists/${checklistId}/checklistItems/${checklistItemId}/customForms/${formId}/meta`;

    return this.construct.get(path, urlParams, headers);
  }

  // PUT /v4/inspections/ { id } / checklists / { checklistId } / checklistItems / { checklistItemId } / customForms
  updateCustomForm(inspectionId: number, checklistId: number, checklistItemId: number, body, urlParams?, headers?) {
    let path = `${this._basePath}/${inspectionId}/checklists/${checklistId}/checklistItems/${checklistItemId}/customForms`;

    return this.construct.update(path, body, urlParams, headers);
  }

  // GET /v4/inspections/{id}/checklists/{checklistId}/checklistItems/{checklistItemId}/customTables
  getCustomTables(inspectionId: number, checklistId: number, checklistItemId: number, urlParams?, headers?) {
    let path = this.checklistItemPath(inspectionId, checklistId, checklistItemId);
    // let path = this.buildPath(inspectionId, 'checklists', checklistId, 'checklistItems', checklistItemId, 'customTables');

    return this.construct.get(path('customTables'), urlParams, headers);
  }

  // GET /v4/inspections/{id}/checklists/{checklistId}/checklistItems/{checklistItemId}/customTables/meta
  getCustomTablesMetaData(inspectionId: number, checklistId: number, checklistItemId: number, urlParams?, headers?) {
    let path = this.buildPath(inspectionId, 'checklists', checklistId, 'checklistItems', checklistItemId, 'customTables','meta');
    return this.construct.get(path, urlParams, headers);
  }

  // GET /v4/inspections/{id}/checklists/{checklistId}/checklistItems/{checklistItemId}/customTables/{tableId}
  getCustomTable(inspectionId: number, checklistId: number, checklistItemId: number, tableId:string, urlParams?, headers?) {
    let path = this.buildPath(inspectionId, 'checklists', checklistId, 'checklistItems', checklistItemId, 'customTables', tableId);
    return this.construct.get(path, urlParams, headers);
  }

  // GET /v4/inspections/{id}/checklists/{checklistId}/checklistItems/{checklistItemId}/customTables/{tableId}/meta
  getCustomTableMetaData(inspectionId: number, checklistId: number, checklistItemId: number, urlParams?, headers?) {
    let path = this.buildPath(inspectionId, 'checklists', checklistId, 'checklistItems', checklistItemId, 'meta');
    return this.construct.get(path, urlParams, headers);
  }

  // PUT /v4/inspections/{id}/checklists/{checklistId}/checklistItems/{checklistItemId}/customTables
  updateCustomTable(inspectionId: number, checklistId: number, checklistItemId: number, body, urlParams?, headers?) {
    let path = this.buildPath(inspectionId, 'checklists', checklistId, 'checklistItems', checklistItemId, 'customTables');
    return this.construct.update(path, body, urlParams, headers);
  }

  // GET /v4/inspections/{inspectionId}/checklists/{checklistId}/checklistItems/{checklistItemId}/documents
  getDocuments(inspectionId: number, checklistId: number, checklistItemId: number, urlParams?, headers?) {
    let path = this.checklistItemPath(inspectionId, checklistId, checklistItemId);
    return this.construct.get(path('documents'), urlParams, headers);
  }

  // POST /v4/inspections/{inspectionId}/checklists/{checklistId}/checklistItems/{checklistItemId}/documents
  addDocument(inspectionId: number, checklistId: number, checklistItemId: number, body, urlParams?, headers?) {
    let path = this.checklistItemPath(inspectionId, checklistId, checklistItemId);
    return this.construct.post(path('documents'), body, urlParams, headers);
  }
 }
