import {Injectable} from '@angular/core';
import {Http, Headers, Response} from '@angular/http';
import {Observable} from 'rxjs/Observable';
import {ConstructApi} from '../construct';

@Injectable()
export class InspectionConditionsApi {
  private _basePath = '/v4/inspections';

  constructor(private construct: ConstructApi) { }

  private conditionsPath(inspectionId, conditionId, ...args) {
    let remainder = args.join('/');
    return `${this._basePath}/${inspectionId}/conditions/${remainder}`;
  }

  //   GET /v4/inspections/{inspectionId}/conditions
  getAll(inspectionId, urlParams?, headers?) {
    return this.construct.get(`${this._basePath}/${inspectionId}/`, urlParams, headers);
  }

  //   GET /v4/inspections/{inspectionId}/conditions/{id}
  get(inspectionId, conditionId, urlParams?, headers?) {
    return this.construct.get(this.conditionsPath(inspectionId, conditionId), urlParams, headers);
  }

  // GET /v4/inspections/ { inspectionId } / conditions / { id } / histories
  getHistory(inspectionId, conditionId, urlParams?, headers?) {
    return this.construct.get(this.conditionsPath(inspectionId, conditionId, 'histories'), urlParams, headers);
  }

  // PUT /v4/inspections/ { inspectionId } / conditions / { id }
  update(inspectionId, conditionId, body, urlParams?, headers?) { 
    return this.construct.update(this.conditionsPath(inspectionId, conditionId, 'histories'), body, urlParams, headers);
  }

  // DELETE /v4/inspections/{inspectionId}/conditions/{ids}
  del(inspectionId, conditionId, urlParams?, headers?) { 
    return this.construct.del(this.conditionsPath(inspectionId, conditionId, 'histories'), urlParams, headers);
  }

  // POST /v4/inspections/ { inspectionId } / conditions
  create(inspectionId, body, urlParams?, headers?) {
    return this.construct.post(`${this._basePath}/${inspectionId}/conditions`, body, urlParams, headers);
  }
}
