import {Injectable} from '@angular/core';
import {Http, Headers, Response} from '@angular/http';
import {Observable} from 'rxjs/Observable';
import {ConstructApi} from '../construct';

@Injectable()
export class InspectionApi {
  private _basePath = '/v4/inspections';

  constructor(private construct:ConstructApi) {}

  search(opts, urlParams?, headers?) {
    return this.construct.search('/v4/search/inspections', opts, urlParams, headers);
  }

  // GET /v4/inspections
  getAll(urlParams?, headers?) {
    return this.construct.get(this._basePath, urlParams, headers);
  }

  // PUT /v4/inspections/{ ids }/assign
  assignInspections(ids:Array<number>, inspectorId, params?, headers?) {
    let args = ids.join(',');
    let path = `${this._basePath}/${args}/assign`;
    let reqParams = Object.assign({}, { inspectorId: inspectorId }, params);

    return this.construct.update(path, null, reqParams, headers);
  }

  // PUT /v4/inspections/{ ids }/assign
  // PUT https://apis.accela.com/v4/inspections/6161316/assign?inspectorId=MINSPECTOR
  assignInspection(id:number, inspectorId, params?, headers?) {
    let path = `${this._basePath}/${id}/assign`;
    let newInspector = { inspectorId: inspectorId };
    let reqParams = Object.assign({}, params, newInspector);

    return this.construct.update(path, null, reqParams, headers);
  }

  // DELETE /v4/inspections/{ ids }/cancel
  cancelInspection(id:number, params?, headers?) {
    return this.construct.del(`${this._basePath}/${id}/cancel`, params, headers);
  }

  cancelInspections(ids:Array<number>, params?, headers?) {
    let args = ids.join(',');
    return this.construct.del(`${this._basePath}/${args}/cancel`, params, headers);
  }

  // POST /v4/inspections/{ id }/related
  createRelatedInspection(id:number, payload, params?, headers?) {
    return this.construct.post(`${this._basePath}/id/related`, payload, params, headers);
  }

  // DELETE /v4/inspections/{ ids }
  deleteInspection(id:number, params?, headers?) {
    return this.construct.del(`${this._basePath}/${id}`, params, headers);
  }

  deleteInspections(ids:Array<number>, params?, headers?) {
    let args = ids.join(',');
    return this.construct.del(`${this._basePath}/${args}`, params, headers);
  }

  // DELETE /v4/inspections/{ id }/related/{ childIds }
  deleteRelatedInspection(id:number, relatedIds:Array<number>, params?, headers?) {
    let childIds = relatedIds.join(',');
    return this.construct.del(`${this._basePath}/${id}/related/${childIds}`, params, headers);
  }

  // GET /v4/inspections/availableDates
  getAvailableDates(params?, headers?) {
    return this.construct.get(`${this._basePath}/availableDates`, params, headers);
  }

  // GET /v4/inspections/{ inspectionIds }/histories
  getHistoriesForInspection(id:number, params?, headers?) {
    return this.construct.get(`${this._basePath}/${id}/histories`, params, headers);
  }

  getHistoriesForInspections(ids:Array<number>, params?, headers?) {
    let args = ids.join(',');
    return this.construct.get(`${this._basePath}/${args}/histories`, params, headers);
  }

  //  GET /v4/inspections/{ ids }
  getInspection(id:number, params?, headers?) {
    return this.construct.get(`${this._basePath}/${id}`, params, headers);
  }

  getInspections(ids:Array<number>, params?, headers?) {
    let args = ids.join(',');
    return this.construct.get(`${this._basePath}/${args}`, params, headers);
  }

  // GET /v4/inspections/{ id }/related
  getRelatedInspections(id:number, params?, headers?) {
    return this.construct.get(`${this._basePath}/${id}/related`, params, headers);
  }

  // PUT /v4/inspections/{ id }/reschedule
  reschedule(id:number, payload, params?, headers?) {
    return this.construct.update(`${this._basePath}/${id}/reschedule`, params, headers);
  }

  // PUT /v4/inspections/{ id }/result
  result(id:number, payload, params?, headers?) {
    return this.construct.update(`${this._basePath}/${id}/result`, params, headers);
  }

  // POST /v4/inspections/schedule
  schedule(payload, params?, headers?) {
    return this.construct.post(`${this._basePath}/schedule`, payload, params, headers);
  }

  // PUT /v4/inspections/{ id }/schedule
  schedulePendingInspection(id:number, params?, headers?) {
    return this.construct.update(`${this._basePath}/${id}/result`, params, headers);
  }

  // PUT /v4/inspections/{ id }
  update(id, payload, params?, headers?) {
    let path = `${this._basePath}/${id}`;
    return this.construct.update(path, payload, params, headers);
  }

  // GET /v4/inspections/ { inspectionId } / comments
  getComments(id, urlParams?, headers?) {
    let path = `${this._basePath}/${id}`;
    return this.construct.get(path, urlParams, headers);
  }
}
