import {Injectable} from '@angular/core';
import {Http, Headers, Response} from '@angular/http';
import {Observable} from 'rxjs/Observable';
import {ConstructApi} from '../construct';

@Injectable()
export class RecordApi {
  private _basePath = '/v4/records';

  constructor(private construct: ConstructApi) {}

  private buildPath(...args) {
    if (!args) {
      return this._basePath;
    }

    return `${this._basePath}/${args.join('/')}`
  }

  search(body) {
    return this.construct.post('/v4/search/records', body);
  }

  searchLocations(recordIds:Array<string>) {
    return this.construct.post('/v4/search/records/location', { ids: recordIds });
  }

  //get_records  GET /v4/records
  getAll(urlParams?, headers?) {
    return this.construct.get(this.buildPath(), urlParams, headers);
  }

  //get_record  GET /v4/records/{ ids }
  getRecord(id:string, urlParams?, headers?) {
    return this.construct.get(this.buildPath(id), urlParams, headers);
  }

  getRecords(ids:Array<string>, urlParams?, headers?) {
    let args = ids.join(',');
    return this.construct.get(this.buildPath(ids), urlParams, headers);
  }

  //  GET /v4/records/{recordId}/conditions
  getRecordConditions(id:string, urlParams?, headers?) {
    return this.construct.get(this.buildPath(id, 'conditions'), urlParams, headers);
  }

  // '/v4/records/' + recordId + '/partTransaction', //entry point
  getRecordParts(id:string, urlParams?, headers?) {
    return this.construct.get(this.buildPath(id, 'partTransaction'), urlParams, headers);
  }

  // 'entryPoint': '/v3/records/' + recordId + '/costs'
  getRecordCosts(id:string, urlParams?, headers?) {
    return this.construct.get(`/v3/records/${id}/costs`, urlParams, headers);
  }
}
